Provides a brief summary of the package libraries on your machine
Value
A data.frame containing the count of packages in each of the user's
libraries. A lib_size column is included if sizes = TRUE.
Examples
lib_summary()
#> Library n_packages
#> 1 /home/runner/work/_temp/Library 66
#> 2 /opt/R/4.4.0/lib/R/library 29
#> 3 /opt/R/4.4.0/lib/R/site-library 1
lib_summary(sizes = TRUE)
#> Library n_packages lib_size
#> 1 /home/runner/work/_temp/Library 66 66078585
#> 2 /opt/R/4.4.0/lib/R/library 29 75732206
#> 3 /opt/R/4.4.0/lib/R/site-library 1 14406443